# -*- coding: utf-8 -*-
"""
Created on Thu Mar 20 13:28:39 2025

@author: mstep
"""

from PIL import Image, ImageDraw, ImageFont

def make_exercise_images(min_number, max_number):
    '''Make exercise images from min_number to max_number inclusive.'''
    # Load the background image.
    bg_image = Image.open('pil_exercise_numbers_bg_image.jpg')

    # Make an image to hold the numbers.
    wid = bg_image.width
    hgt = bg_image.height
    number_image = Image.new('RGBA', (wid, hgt), 'white')
    number_dr = ImageDraw.Draw(number_image)

    # Load the fixed mask in grayscale.
    fixed_mask = Image.open('pil_exercise_numbers_fixed_mask.png').convert('L')

    # Make the number mask.
    number_mask = Image.new('L', (wid, hgt), 'black')
    number_mask_dr = ImageDraw.Draw(number_mask)

    # Make the final mask.
    final_mask = Image.new('L', (wid, hgt), 'black')
    final_mask_dr = ImageDraw.Draw(final_mask)

    # Define the numbers area.
    xmin = 40
    ymin = 150
    xmax = 570
    ymax = 670
    cx = (xmin + xmax) / 2
    cy = (ymin + ymax) / 2

    # Define the font.
    font_size = 300
    font = ImageFont.truetype("arialbd.ttf", font_size)

    # Get the length of the largest number.
    digits = len(f'{max_number}')

    # Create the numbered images.
    for number in range(min_number, max_number + 1):
        print(number)

        # Clear the number mask.
        number_mask_dr.rectangle([0, 0, wid, hgt], fill='black')

        # Draw the number on the foreground and number mask images.
        text = f'{number}'
        text_color = 'lightgreen'
        outline_color = 'black'
        for i in range(5):
            for dx in range(-i, i + 1):
                for dy in range(-i, i + 1):
                    number_dr.text((cx+dx, cy+dy), text, font=font,
                        fill=outline_color, anchor='mm', align='center')
                    number_mask_dr.text((cx+dx, cy+dy), text, font=font,
                        fill='white', anchor='mm', align='center')
        number_dr.text((cx, cy), text=text, fill=text_color, font=font,
            anchor='mm', align='center')

        number_image.save('pil_exercise_numbers_number_image.png') # Save for debugging.
        number_mask.save('pil_exercise_numbers_number_mask.png') # Save for debugging.

        # Clear the final mask.
        final_mask_dr.rectangle([0, 0, wid, hgt], fill='black')

        # Paste the number mask onto the final mask but
        # only in places where the fixed mask is white.
        final_mask.paste(number_mask, (0, 0), fixed_mask)
        final_mask.save('pil_exercise_numbers_final_mask.png') # Save for debugging.

        # Overlay the number picture on the background picuture but
        # only where the final mask is white.
        bg_copy = bg_image.copy()
        bg_copy.paste(number_image, (0, 0), final_mask)

        # Save the result.
        bg_copy.save(f'exercise_{number:0{digits}d}.jpg')


make_exercise_images(1, 10)
print('Done')
